@@ -2,7 +2,6 @@ import datetime
 import textwrap
 from pathlib import Path
 
-from slap import __version__
 from slap.application import Application, Command, argument, option
 from slap.plugins import ApplicationPlugin
 from slap.util.external.licenses import get_spdx_license_details, wrap_license_text
@@ -126,7 +125,7 @@ TEMPLATES = {
                     python-version: [ "3.6", "3.7", "3.8", "3.9", "3.10", "3.x" ]
                 steps:
                 - uses: actions/checkout@v2
-                - uses: python-slap/slap.cli@gha/install/v1
+                - uses: python-slap/slap-cli@gha/install/v1
                 - uses: actions/setup-python@v2
                   with: {{ python-version: "${{{{ matrix.python-version }}}}" }}
                 - run: slap install -vv --no-venv-check
@@ -137,7 +136,7 @@ TEMPLATES = {
                 if: github.event_name == 'pull_request'
                 steps:
                   - uses: actions/checkout@v2
-                  - uses: python-slap/slap.cli@gha/changelog/update/v1
+                  - uses: python-slap/slap-cli@gha/changelog/update/v1
     """,
     },
 }
@@ -252,7 +251,7 @@ class InitCommandPlugin(ApplicationPlugin, Command):
             if self.option("as-markdown"):
                 print(f'```{path.suffix[1:]} title="{path}"')
                 print(content, "    ")
-                print(f"```\n\n")
+                print("```\n\n")
                 continue
 
             if path.exists() and not self.option("overwrite"):
